pub struct BoxedHandler<Ctx, R>(/* private fields */);Expand description
A type-erased handler that owns a Box<dyn Fn(...)>.
Use this only when you need to store handlers in a collection or return them from a function with an erased type. In hot paths, prefer the zero-cost combinator structs.
Constructed via HandlerExt::boxed.
Example
use tree_sitter_utils::{handler_fn, HandlerExt, BoxedHandler, Input};
let h: BoxedHandler<(), String> =
handler_fn(|_: Input<()>| "hello".to_owned()).boxed();
let _ = h;Implementations
Sourceimpl<Ctx, R> BoxedHandler<Ctx, R>
impl<Ctx, R> BoxedHandler<Ctx, R>
Sourcepub fn new<F>(f: F) -> Self
pub fn new<F>(f: F) -> Self
Wrap a boxed closure as a BoxedHandler.